.. miniSEED documentation master file

.. _software:

Software
========

A variety of open-source software packages are available to that support
the miniSEED format.

Validation
----------

The `mseed3-utils <https://github.com/EarthScope/mseed3-utils>`_ project includes the following programs:

- mseed3-validator - a validator for the miniSEED 3 formatted files
- mseed2text - convert miniSEED 3 format to a text representation
- mseed2json - convert miniSEED 3 format to a JSON representation

Download `mseed3-utils releases <https://github.com/EarthScope/mseed3-utils/releases>`_

mseedconvert
------------

The `mseedconvert <https://github.com/EarthScope/mseedconvert>`_ program
converts miniSEED between versions and data encodings.

Download `mseedconvert releases <https://github.com/EarthScope/mseedconvert/releases>`_

libmseed
--------

A general library (C language) for reading and writing miniSEED.  Release versions 3.x support both
this specification and version 2 of the format.

Download `libmseed releases <https://github.com/EarthScope/libmseed/releases>`_

